# Key Fingerprints

!!! hint

    The key fingerprints of login and export nodes can occasionally change. This page holds
    up-to-date fingerprints.

Each cluster can be accessed via so-called **login nodes** using specific hostnames. All login nodes
of a cluster share common SSH key fingerprints that are unique. When connecting to one of our HPC
systems via the corresponding login nodes, please make sure that the provided fingerprint matches
one of the table. This is the only way to ensure you are connecting to the correct server from the
very beginning. If the **fingerprint differs**, please contact the
[HPC support team](../support/support.md).

In case an additional login node of the same cluster is used, the key needs to be checked and
approved again.

??? example "Connecting with SSH to Barnard"

    ```console
    marie@local$ ssh login1.barnard.hpc.tu-dresden.de
    The authenticity of host 'login1.barnard.hpc.tu-dresden.de (172.24.95.28)' can't be established.
    ECDSA key fingerprint is SHA256:8Coljw7yoVH6HA8u+K3makRK9HfOSfe+BG8W/CUEPp0.
    Are you sure you want to continue connecting (yes/no)?
    ```

    In this case, the fingerprint matches the one given in the table. Thus, you can proceed by
    typing 'yes'.

??? info "Verify key fingerprints without login"

    To verify the fingerprint without login, use `ssh-keyscan` and `ssh-keygen`:

    ```console
    marie@local$ ssh-keyscan login1.barnard.hpc.tu-dresden.de 2>/dev/null | ssh-keygen -l -f -
    3072 SHA256:lVQOvnci07jkxmFnX58pQf3cD7lz1mf4K4b9jZrAlVU login1.barnard.hpc.tu-dresden.de (RSA)
    256 SHA256:Xan2MYazewT0V5agNazaQfWzLKBD3P48zRwR6reoXhI login1.barnard.hpc.tu-dresden.de (ECDSA)
    256 SHA256:Gn4n5IX9eEvkpOGrtZzs9T9yAfJUB200bgRchchiKAQ login1.barnard.hpc.tu-dresden.de (ED25519)
    ```

## Barnard

The cluster [`Barnard`](../jobs_and_resources/barnard.md) can be accessed via the
four login nodes `login[1-4].barnard.hpc.tu-dresden.de`. (Please choose one concrete login node when
connecting, see example below.)

| Key Type | Fingerprint                                           |
|:---------|:------------------------------------------------------|
| RSA      | `SHA256:lVQOvnci07jkxmFnX58pQf3cD7lz1mf4K4b9jZrAlVU`  |
| RSA      | `MD5:5b:39:ae:03:3a:60:15:21:4b:e8:ba:72:52:b8:a1:ad` |
| ECDSA    | `SHA256:Xan2MYazewT0V5agNazaQfWzLKBD3P48zRwR6reoXhI`  |
| ECDSA    | `MD5:02:fd:ab:c8:39:f9:94:cc:3f:e0:7e:78:5f:76:b8:4c` |
| ED25519  | `SHA256:Gn4n5IX9eEvkpOGrtZzs9T9yAfJUB200bgRchchiKAQ`  |
| ED25519  | `MD5:e8:10:96:67:e8:4c:fd:87:f0:c6:4e:e8:1f:53:a9:be` |
{: summary="List of valid fingerprints for Barnard login[1-4] nodes"}

## Romeo

The cluster [`Romeo`](../jobs_and_resources/romeo.md) can be accessed via the two
login nodes `login[1-2].romeo.hpc.tu-dresden.de`. (Please choose one concrete login node when
connecting, see example below.)

| Key Type | Fingerprint                                           |
|:---------|:------------------------------------------------------|
|RSA       | `SHA256:BvYEYJtIYDGr3U0up58q5F7aog7JA2RP+w53XKmwO8I`  |
|RSA       | `MD5:5d:dc:40:3b:8b:89:77:5d:0f:29:84:31:0f:73:25:9f` |
|ECDSA     | `SHA256:lgxNRgGcKe7oDGuwf0WV9VPukA30kEqg0sNDLLQwu8Y`  |
|ECDSA     | `MD5:e1:bd:e4:77:06:97:f9:f3:03:18:56:66:14:5d:8d:18` |
|ED25519   | `SHA256:QNjH0ulelqykywMkt3UNTG4W1HzRkHqrhu0f6oq302I`  |
|ED25519   | `MD5:e4:4e:7a:76:aa:87:da:17:92:b1:17:c6:a1:25:29:7e` |
{: summary="List of valid fingerprints for Romeo login[1-2] node"}

## Capella

The cluster [`Capella`](../jobs_and_resources/capella.md) can be accessed via the two
login nodes `login[1-2].capella.hpc.tu-dresden.de`. (Please choose one concrete login node when
connecting, see example below.)

| Key Type | Fingerprint                                           |
|:---------|:------------------------------------------------------|
|RSA       | ``  |
|RSA       | `` |
|ECDSA     | ``  |
|ECDSA     | `` |
|ED25519   | ``  |
|ED25519   | `` |
{: summary="List of valid fingerprints for Capella login[1-2] node"}

## Alpha Centauri

The cluster [`Alpha Centauri`](../jobs_and_resources/alpha_centauri.md) can be accessed via the two
login nodes `login[1-2].alpha.hpc.tu-dresden.de`. (Please choose one concrete login node when
connecting, see example below.)

| Key Type | Fingerprint                                           |
|:---------|:------------------------------------------------------|
| RSA      | `SHA256:BvYEYJtIYDGr3U0up58q5F7aog7JA2RP+w53XKmwO8I`  |
| RSA      | `MD5:5d:dc:40:3b:8b:89:77:5d:0f:29:84:31:0f:73:25:9f` |
| ECDSA    | `SHA256:lgxNRgGcKe7oDGuwf0WV9VPukA30kEqg0sNDLLQwu8Y`  |
| ECDSA    | `MD5:e1:bd:e4:77:06:97:f9:f3:03:18:56:66:14:5d:8d:18` |
| ED25519  | `SHA256:QNjH0ulelqykywMkt3UNTG4W1HzRkHqrhu0f6oq302I`  |
| ED25519  | `MD5:e4:4e:7a:76:aa:87:da:17:92:b1:17:c6:a1:25:29:7e` |
{: summary="List of valid fingerprints for Alpha Centauri login[1-2] node"}

## Julia

The cluster [`Julia`](../jobs_and_resources/julia.md) can be accessed via `julia.hpc.tu-dresden.de`.
(Note, there is no separate login node.)

| Key Type | Fingerprint                                           |
|:---------|:------------------------------------------------------|
| RSA      | `SHA256:MPRhcFxLstI76W8Sg/5KiQlGPVOHUGM/B0+qIZHFj9E`  |
| RSA      | `MD5:5f:22:e2:e2:c3:dc:b1:ee:a9:ba:61:af:34:f6:27:f0` |
| ECDSA    | `SHA256:LkHMlx6VewoPBvOhmNbue8kBsvlljtsEAjCZA8vxRWc`  |
| ECDSA    | `MD5:3f:5a:f2:f9:9d:30:5c:83:c0:e5:0e:87:42:1a:d8:b0` |
| ED25519  | `SHA256:k5zc2E0Y8zcLErDD1Ej3g0OqkoLDF22ADmfX+b+8Z9g`  |
| ED25519  | `MD5:41:03:a2:7c:e9:4d:1c:bd:30:77:7d:91:d7:93:9f:8c` |
{: summary="List of valid fingerprints for Julia login node"}

## Power9

The cluster [`Power9`](../jobs_and_resources/hardware_overview.md#power9) can be accessed via the
two login nodes `login[1-2].power9.hpc.tu-dresden.de`. (Please choose one concrete login node when
connecting, see example below.)

| Key Type | Fingerprint                                           |
|:---------|:------------------------------------------------------|
| RSA      | `SHA256:BvYEYJtIYDGr3U0up58q5F7aog7JA2RP+w53XKmwO8I`  |
| RSA      | `MD5:5d:dc:40:3b:8b:89:77:5d:0f:29:84:31:0f:73:25:9f` |
| ECDSA    | `SHA256:lgxNRgGcKe7oDGuwf0WV9VPukA30kEqg0sNDLLQwu8Y`  |
| ECDSA    | `MD5:e1:bd:e4:77:06:97:f9:f3:03:18:56:66:14:5d:8d:18` |
| ED25519  | `SHA256:QNjH0ulelqykywMkt3UNTG4W1HzRkHqrhu0f6oq302I`  |
| ED25519  | `MD5:e4:4e:7a:76:aa:87:da:17:92:b1:17:c6:a1:25:29:7e` |
{: summary="List of valid fingerprints for Power9 login[1-2] nodes"}

## Dataport Nodes

When you transfer files using the [dataport nodes](../data_transfer/dataport_nodes.md), please make
sure that the fingerprint shown matches one of the table.

| Key Type | Fingerprint                                           |
|:---------|:------------------------------------------------------|
| RSA      | `SHA256:t4Vl4rHRHbglZIm+hck2MWld+0smYAb2rx7EGWWmya0`  |
| RSA      | `MD5:59:7f:c1:7b:34:ec:c8:07:3d:fe:b8:b5:6a:96:ea:0c` |
| ECDSA    | `SHA256:Ga1dXpp1yM5GRJC77PgDCQwDy7oHdrTY7z11V1Eq1L8`  |
| ECDSA    | `MD5:43:1b:b8:f6:23:ab:4a:08:dc:a1:b3:09:8c:8c:be:f9` |
| ED25519  | `SHA256:SRYDLKt7YTQkXmkv+doWV/b55xQz1nT4ZZtXYGhydg4`  |
| ED25519  | `MD5:eb:96:21:d7:61:9f:39:10:82:b9:21:e9:4a:87:c2:9a` |
{: summary="List of valid fingerprints for dataport1.hpc.tu-dresden.de"}

| Key Type | Fingerprint                                           |
|:---------|:------------------------------------------------------|
| RSA      | `SHA256:aMVmc3E0+ndXPiQ8EpY6lFk5CFdfGJfjy/0UBcxor58`  |
| RSA      | `MD5:03:b8:8a:2b:10:e5:6b:c8:0b:78:ab:4e:5b:2c:0e:2c` |
| ECDSA    | `SHA256:6t69R86zhJjGDlIobdsSbKFn8Km3cs9JYWlDW22nEvI`  |
| ECDSA    | `MD5:58:70:7d:df:e5:c8:43:cf:a5:75:ad:f5:da:9f:1a:6d` |
| ED25519  | `SHA256:KAD9xwCRK5C8Ch6Idfnfy88XrzZcqEJ9Ms6O+AzGfDE`  |
| ED25519  | `MD5:2b:61:5a:89:fe:96:95:0d:3d:f6:29:40:55:ea:e6:11` |
{: summary="List of valid fingerprints for dataport2.hpc.tu-dresden.de"}
